@@ -3,7 +3,7 @@
 # Apache::Session::Lock::Semaphore
 # IPC Semaphore locking for Apache::Session
 # Copyright(c) 1998, 1999, 2000 Jeffrey William Baker (jwbaker@acm.org)
-# Distribute under the Artistic License
+# Distribute under the Perl License
 #
 ############################################################################
 
@@ -15,15 +15,16 @@ use IPC::SysV qw(IPC_PRIVATE IPC_CREAT S_IRWXU SEM_UNDO);
 use IPC::Semaphore;
 use vars qw($VERSION);
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 BEGIN {
 
     if ($Config{'osname'} eq 'linux') {
         #More semaphores on Linux means less lock contention
         $Apache::Session::Lock::Semaphore::nsems = 32;
-    }
-    else {
+    } elsif ($Config{'osname'} eq 'freebsd') {
+        $Apache::Session::Lock::Semaphore::nsems = 8; #copied from IPC::Semaphore/sem.t minus 1
+    } else {
         $Apache::Session::Lock::Semaphore::nsems = 16;
     }
     
@@ -175,6 +176,13 @@ sub hash {
 
 }
 
+sub remove {
+    my $self    = shift;
+    if ($self->{sem}) {    
+        $self->{sem}->remove();
+    }
+}
+
 1;
 
 
@@ -187,10 +195,10 @@ Apache::Session::Lock::Semaphore - Provides mutual exclusion through semaphores
 =head1 SYNOPSIS
 
  use Apache::Session::Lock::Semaphore;
- 
+
  my $locker = new Apache::Session::Lock::Semaphore;
  die "no semaphores" unless $locker;
- 
+
  $locker->acquire_read_lock($ref);
  $locker->acquire_write_lock($ref);
  $locker->release_read_lock($ref);
